#include "RedbearNanoV2_board.h"
/*
   (c)2014-2017 Forward Computing and Control Pty. Ltd.
   NSW Australia, www.forward.com.au
   This code is not warranted to be fit for any purpose. You may only use it at your own risk.
   This generated code may be freely used for both private and commercial use
   provided this copyright is maintained.
*/

// dimensions in 0.5*1/10"
RedbearNanoV2_board::RedbearNanoV2_board(pfodDwgs *_dwgsPtr)  : pfodControl(_dwgsPtr)  {
  z_idx = pfodDwgs::reserveIdx(1); // LED indicator
  ledState = 0;
}

void RedbearNanoV2_board::setLedCmd(byte c) {
  ledCmd = c;
}

// sets 0 for On, 1 for Off, Nano v2 LED is active HIGH
void RedbearNanoV2_board::setLed(byte off) {
  ledState = off;
}

// returns 0 for On, 1 for Off, Nano v2 LED is active HIGH
byte RedbearNanoV2_board::getLed() {
  return ledState;
}

void RedbearNanoV2_board::setBase(int c, int r) {
  baseCol = c;
  baseRow = r;
}

int RedbearNanoV2_board::getBaseCol() {
  return baseCol;
}

int RedbearNanoV2_board::getBaseRow() {
  return baseRow;
}


void RedbearNanoV2_board::drawFirst() {
  dwgsPtr->pushZero(baseCol, baseRow);
  dwgsPtr->pushZero(colPadding, rowPadding);
}

void RedbearNanoV2_board::drawLast() {
  update(); // update with current state
  dwgsPtr->popZero(); // undo move
  dwgsPtr->popZero(); // undo move
}
void RedbearNanoV2_board::drawPad(int offsetC) {
  dwgsPtr->rectangle().size(0.8, 1.25).filled().color(dwgsPtr->SILVER).offset(offsetC, 0).send();
}

void RedbearNanoV2_board::drawPinHole(int offsetR) {
  dwgsPtr->circle().radius(0.5).filled().color(dwgsPtr->SILVER).offset(0, offsetR).send();
  dwgsPtr->circle().radius(0.15).filled().color(dwgsPtr->WHITE).offset(0, offsetR).send();
}

void RedbearNanoV2_board::drawPins() {

  dwgsPtr->pushZero(1, boardRows - 1);
  for (int i = 0; i < 6; i++) {
    drawPinHole(-i * 2);
  }
  dwgsPtr->popZero();
  dwgsPtr->pushZero(boardCols - 1, boardRows - 1); // bottom right
  for (int i = 0; i < 6; i++) {
    drawPinHole(-i * 2);
  }
  dwgsPtr->popZero();

  dwgsPtr->pushZero(2.5, boardRows - 1.25);
  for (int i = 0; i < 5; i++) {
    drawPad(i * 2);
  }
  dwgsPtr->popZero();
}
void RedbearNanoV2_board::drawLedTxt() {
  dwgsPtr->pushZero(-4, 2);
  drawLed();
  dwgsPtr->label().text(F("LED")).fontSize(-7).bold().color(dwgsPtr->WHITE).offset(-2, 0).send();
  dwgsPtr->label().text(F("D13")).fontSize(-7).bold().color(dwgsPtr->WHITE).offset(2, 0).send();
  dwgsPtr->popZero();
}

void RedbearNanoV2_board::drawLeftNames() {
  dwgsPtr->pushZero(baseCol - 3, boardRows - 1 + baseRow);
  dwgsPtr->label().text(F("SWCLK")).fontSize(-7).bold().offset(0, -10).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("SWDIO")).fontSize(-7).bold().offset(0.15, -8).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("A4")).fontSize(-7).bold().offset(1.25, -6).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("A5")).fontSize(-7).bold().offset(1.25, -4).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("GND")).fontSize(-7).bold().offset(0.75, -2).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("VIN")).fontSize(-7).bold().offset(1, -0).color(dwgsPtr->WHITE).send();
  dwgsPtr->popZero();
}

void RedbearNanoV2_board::drawRightNames() {
  dwgsPtr->pushZero(baseCol + boardCols + 2, boardRows - 1 + baseRow);
  dwgsPtr->label().text(F("VDD")).fontSize(-7).bold().offset(0, -10).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("CTS")).fontSize(-7).bold().offset(0, -8).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("TXD")).fontSize(-7).bold().offset(0, -6).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("RXT")).fontSize(-7).bold().offset(0, -4).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("RTS")).fontSize(-7).bold().offset(0, -2).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("GND")).fontSize(-7).bold().offset(0, -0).color(dwgsPtr->WHITE).send();
  dwgsPtr->popZero();
}

void RedbearNanoV2_board::drawBottomNames() {
  dwgsPtr->pushZero(baseCol + 3, boardRows + baseRow + 1.25 - 3.5);
  dwgsPtr->label().text(F("D10")).fontSize(-7).bold().offset(-0.25, 0).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("D9")).fontSize(-7).bold().offset(2, 0).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("D8")).fontSize(-7).bold().offset(4, 0).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("D7")).fontSize(-7).bold().offset(6, 0).color(dwgsPtr->WHITE).send();
  dwgsPtr->label().text(F("D6")).fontSize(-7).bold().offset(8, 0).color(dwgsPtr->WHITE).send();
  dwgsPtr->popZero();
}


void RedbearNanoV2_board::draw() {
  drawOutline();
}

void RedbearNanoV2_board::drawOutline() {
  dwgsPtr->rectangle().filled().size(boardCols, boardRows).color(160).send();
  dwgsPtr->label().bold().color(dwgsPtr->WHITE).text(F("RedBear.cc ")).fontSize(-6).offset(7, 1).send();
  dwgsPtr->label().bold().color(dwgsPtr->WHITE).text(F("BLE Nano v2.0")).fontSize(-6).offset(7, 3).send();
}

void RedbearNanoV2_board::drawLed() {
  dwgsPtr->index().idx(z_idx).send(); // place holder
  dwgsPtr->touchZone().cmd(ledCmd).centered().filter(dwgsPtr->TOUCH).send();
  dwgsPtr->touchAction().cmd(ledCmd).action( // create the action
    dwgsPtr->rectangle().idx(z_idx).filled().color(dwgsPtr->BLACK).centered() //
  ).send(); // send the touchAction
  updateLed();
}

void RedbearNanoV2_board::updateLed() {
  if (ledState == 1) { // note on Nano v2 LED is ON when output HIGH so == 1 is ON
    dwgsPtr->rectangle().idx(z_idx).filled().color(118).centered().send();
  } else {
    dwgsPtr->rectangle().idx(z_idx).filled().color(dwgsPtr->WHITE).centered().send();
  }
}

void RedbearNanoV2_board::update() {
  updateLed();
}

